@@ -201,7 +201,9 @@ static void keyindex_construct(pmix_keyindex_t *ki)
     pmix_tma_t *const tma = pmix_obj_get_tma(&ki->super);
 
     ki->table = PMIX_NEW(pmix_pointer_array_t, tma);
-    ki->next_id = PMIX_INDEX_BOUNDARY;
+    pmix_pointer_array_init(ki->table, 1024, INT_MAX, 128);
+
+    ki->next_id = 0;
 }
 
 static void keyindex_destruct(pmix_keyindex_t *ki)
@@ -318,6 +320,7 @@ static void iofreqcon(pmix_iof_req_t *p)
     p->remote_id = 0;
     p->procs = NULL;
     p->nprocs = 0;
+    memset(&p->flags, 0, sizeof(pmix_iof_flags_t));
     p->channels = PMIX_FWD_NO_CHANNELS;
     p->cbfunc = NULL;
     p->regcbfunc = NULL;
@@ -582,9 +585,11 @@ static void grdes(pmix_group_t *p)
 {
     if (NULL != p->grpid) {
         free(p->grpid);
+        p->grpid = NULL;
     }
     if (NULL != p->members) {
         PMIX_PROC_FREE(p->members, p->nmbrs);
+        p->members = NULL;
     }
 }
 PMIX_CLASS_INSTANCE(pmix_group_t,
