@@ -19,7 +19,7 @@
  * Copyright (c) 2015      Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  * Copyright (c) 2021-2023 Nanook Consulting.  All rights reserved.
- * Copyright (c) 2022      Triad National Security, LLC. All rights reserved.
+ * Copyright (c) 2022-2023 Triad National Security, LLC. All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -46,6 +46,7 @@
 #include "src/mca/plog/base/base.h"
 #include "src/mca/pnet/base/base.h"
 #include "src/mca/preg/base/base.h"
+#include "src/mca/prm/base/base.h"
 #include "src/mca/psec/base/base.h"
 #include "src/mca/psquash/base/base.h"
 #include "src/mca/pstrg/base/base.h"
@@ -53,6 +54,7 @@
 #include "src/util/pmix_name_fns.h"
 #include "src/util/pmix_net.h"
 #include "src/util/pmix_output.h"
+#include "src/util/pmix_printf.h"
 #include "src/util/pmix_show_help.h"
 
 #include "src/client/pmix_client_ops.h"
@@ -114,8 +116,7 @@ PMIX_EXPORT pmix_globals_t pmix_globals = {
     .external_topology = false,
     .external_progress = false,
     .iof_flags = PMIX_IOF_FLAGS_STATIC_INIT,
-    .keyindex = PMIX_POINTER_ARRAY_STATIC_INIT,
-    .next_keyid = PMIX_INDEX_BOUNDARY
+    .keyindex = PMIX_KEYINDEX_STATIC_INIT
 };
 
 static void _notification_eviction_cbfunc(struct pmix_hotel_t *hotel, int room_num, void *occupant)
@@ -128,6 +129,20 @@ static void _notification_eviction_cbfunc(struct pmix_hotel_t *hotel, int room_n
 
 static bool util_initialized = false;
 
+void pmix_expose_param(char *param)
+{
+    char *value, *pm;
+
+    value = strchr(param, '=');
+    *value = '\0';
+    ++value;
+    pmix_asprintf(&pm, "PMIX_MCA_%s", param);
+    setenv(pm, value, true);
+    free(pm);
+    --value;
+    *value = '=';
+}
+
 int pmix_init_util(pmix_info_t info[], size_t ninfo, char *libdir)
 {
     pmix_status_t ret;
@@ -212,6 +227,7 @@ int pmix_rte_init(uint32_t type, pmix_info_t info[], size_t ninfo, pmix_ptl_cbfu
     pmix_info_t *iptr;
     size_t minfo;
     bool keepfqdn = false;
+    pmix_iof_flags_t flags;
 
 #if PMIX_NO_LIB_DESTRUCTOR
     if (pmix_init_called) {
@@ -226,6 +242,7 @@ int pmix_rte_init(uint32_t type, pmix_info_t info[], size_t ninfo, pmix_ptl_cbfu
 #endif
 
     pmix_init_called = true;
+    memset(&flags, 0, sizeof(pmix_iof_flags_t));
 
     if (PMIX_SUCCESS != pmix_init_util(info, ninfo, NULL)) {
         return PMIX_ERROR;
@@ -275,7 +292,7 @@ int pmix_rte_init(uint32_t type, pmix_info_t info[], size_t ninfo, pmix_ptl_cbfu
             } else if (PMIX_CHECK_KEY(&info[n], PMIX_BIND_REQUIRED)) {
                 pmix_bind_progress_thread_reqd = PMIX_INFO_TRUE(&info[n]);
             } else {
-                pmix_iof_check_flags(&info[n], &pmix_globals.iof_flags);
+                pmix_iof_check_flags(&info[n], &flags);
             }
         }
     }
@@ -313,9 +330,8 @@ int pmix_rte_init(uint32_t type, pmix_info_t info[], size_t ninfo, pmix_ptl_cbfu
     ret = pmix_hotel_init(&pmix_globals.notifications, pmix_globals.max_events, pmix_globals.evbase,
                           pmix_globals.event_eviction_time, _notification_eviction_cbfunc);
     PMIX_CONSTRUCT(&pmix_globals.nspaces, pmix_list_t);
-    PMIX_CONSTRUCT(&pmix_globals.keyindex, pmix_pointer_array_t);
-    pmix_pointer_array_init(&pmix_globals.keyindex, 1024, INT_MAX, 128);
-    /* tools as well as servers can belong to groups */
+    PMIX_CONSTRUCT(&pmix_globals.keyindex, pmix_keyindex_t);
+    pmix_pointer_array_init(pmix_globals.keyindex.table, 1024, INT_MAX, 128);
     PMIX_CONSTRUCT(&pmix_client_globals.groups, pmix_list_t);
     /* need to hold off checking the hotel init return code
      * until after we construct all the globals so they can
@@ -330,7 +346,7 @@ int pmix_rte_init(uint32_t type, pmix_info_t info[], size_t ninfo, pmix_ptl_cbfu
     pmix_pointer_array_init(&pmix_globals.iof_requests, 128, INT_MAX, 128);
     /* setup the stdin forwarding target list */
     PMIX_CONSTRUCT(&pmix_globals.stdin_targets, pmix_list_t);
-    memset(&pmix_globals.iof_flags, 0, sizeof(pmix_iof_flags_t));
+    memcpy(&pmix_globals.iof_flags, &flags, sizeof(pmix_iof_flags_t));
 
     /* Setup client verbosities as all procs are allowed to
      * access client APIs */
@@ -549,6 +565,19 @@ int pmix_rte_init(uint32_t type, pmix_info_t info[], size_t ninfo, pmix_ptl_cbfu
         goto return_error;
     }
 
+    /* open and initialize */
+    ret = pmix_mca_base_framework_open(&pmix_prm_base_framework, PMIX_MCA_BASE_OPEN_DEFAULT);
+    if (PMIX_SUCCESS != ret) {
+        error = "pmix_prm_base_open";
+        goto return_error;
+    }
+
+    ret = pmix_prm_base_select();
+    if (PMIX_SUCCESS != ret) {
+        error = "pmix_prm_base_select";
+        goto return_error;
+    }
+
     /* initialize the attribute support system */
     pmix_init_registered_attrs();
 
