@@ -8,7 +8,8 @@
  * Copyright (c) 2016      Mellanox Technologies, Inc.
  *                         All rights reserved.
  * Copyright (c) 2016      IBM Corporation.  All rights reserved.
- * Copyright (c) 2021-2023 Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2024 Nanook Consulting  All rights reserved.
+ * Copyright (c) 2024      Triad National Security, LLC. All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -83,11 +84,12 @@ PMIX_CLASS_INSTANCE(pmix_dmdx_reply_caddy_t, pmix_object_t, dcd_con, NULL);
 
 static void dmdx_cbfunc(pmix_status_t status, const char *data, size_t ndata, void *cbdata,
                         pmix_release_cbfunc_t relfn, void *relcbdata);
-static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
+static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank, char *key,
                                       pmix_server_caddy_t *cd, bool diffnspace, pmix_scope_t scope,
                                       pmix_modex_cbfunc_t cbfunc, void *cbdata);
-static pmix_status_t create_local_tracker(char nspace[], pmix_rank_t rank, pmix_info_t info[],
-                                          size_t ninfo, pmix_modex_cbfunc_t cbfunc, void *cbdata,
+static pmix_status_t create_local_tracker(char nspace[], pmix_rank_t rank, char *key,
+                                          pmix_info_t info[], size_t ninfo,
+                                          pmix_modex_cbfunc_t cbfunc, void *cbdata,
                                           pmix_dmdx_local_t **lcd, pmix_dmdx_request_t **rq);
 static pmix_status_t get_job_data(char *nspace, pmix_server_caddy_t *cd,
                                   char *key, pmix_buffer_t *pbkt);
@@ -104,8 +106,9 @@ static void relfn(void *cbdata)
     }
 }
 
-static pmix_status_t defer_response(char *nspace, pmix_rank_t rank, pmix_server_caddy_t *cd,
-                                    bool localonly, pmix_modex_cbfunc_t cbfunc, void *cbdata,
+static pmix_status_t defer_response(char *nspace, pmix_rank_t rank, char *key,
+                                    pmix_server_caddy_t *cd, bool localonly,
+                                    pmix_modex_cbfunc_t cbfunc, void *cbdata,
                                     struct timeval *tv, pmix_dmdx_local_t **locald)
 {
     pmix_status_t rc;
@@ -116,19 +119,22 @@ static pmix_status_t defer_response(char *nspace, pmix_rank_t rank, pmix_server_
 
     if (localonly) {
         /* the client asked that we not wait, so return now */
-        pmix_output_verbose(2, pmix_server_globals.get_output, "%s:%d CLIENT REQUESTED IMMEDIATE",
+        pmix_output_verbose(2, pmix_server_globals.get_output,
+                            "%s:%d CLIENT REQUESTED IMMEDIATE",
                             pmix_globals.myid.nspace, pmix_globals.myid.rank);
         return PMIX_ERR_NOT_AVAILABLE;
     }
     /* we cannot do anything further, so just track this request
      * for now */
-    rc = create_local_tracker(nspace, rank, cd->info, cd->ninfo, cbfunc, cbdata, &lcd, &req);
+    rc = create_local_tracker(nspace, rank, key, cd->info, cd->ninfo, cbfunc, cbdata, &lcd, &req);
     if (PMIX_ERR_NOMEM == rc || NULL == lcd) {
         return rc;
     }
-    pmix_output_verbose(2, pmix_server_globals.get_output, "%s:%d TRACKER CREATED - WAITING",
-                        pmix_globals.myid.nspace, pmix_globals.myid.rank);
-    /* if they specified a timeout, set it up now */
+    pmix_output_verbose(2, pmix_server_globals.get_output,
+                        "%s:%d TRACKER CREATED - WAITING TIMEOUT %d",
+                        pmix_globals.myid.nspace, pmix_globals.myid.rank,
+                       (NULL == tv) ? -1 : (int)tv->tv_sec);
+     /* if they specified a timeout, set it up now */
     if (NULL != tv && 0 < tv->tv_sec) {
         pmix_event_evtimer_set(pmix_globals.evbase, &req->ev, get_timeout, req);
         pmix_event_evtimer_add(&req->ev, tv);
@@ -139,6 +145,7 @@ static pmix_status_t defer_response(char *nspace, pmix_rank_t rank, pmix_server_
     *locald = lcd;
     return rc;
 }
+
 pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_server_caddy_t *cd = (pmix_server_caddy_t *) cbdata;
@@ -167,7 +174,8 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
     pmix_scope_t scope = PMIX_SCOPE_UNDEF;
     pmix_rank_info_t *iptr;
 
-    pmix_output_verbose(2, pmix_server_globals.get_output, "%s recvd GET",
+    pmix_output_verbose(2, pmix_server_globals.get_output,
+                        "%s recvd GET",
                         PMIX_NAME_PRINT(&pmix_globals.myid));
 
     /* setup */
@@ -329,7 +337,8 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
     pmix_output_verbose(2, pmix_server_globals.get_output,
                         "%s EXECUTE GET FOR %s:%d WITH KEY %s ON BEHALF OF %s",
                         PMIX_NAME_PRINT(&pmix_globals.myid), nspace, rank,
-                        (NULL == key) ? "NULL" : key, PMIX_PNAME_PRINT(&cd->peer->info->pname));
+                        (NULL == key) ? "NULL" : PMIx_Get_attribute_name(key),
+                        PMIX_PNAME_PRINT(&cd->peer->info->pname));
 
     /* This call flows upward from a local client. If we don't
      * know about this nspace, then it cannot refer to the
@@ -398,9 +407,11 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
      * we do know how many clients to expect, so first check to see if
      * all clients have been registered with us */
     if (!nptr->all_registered) {
-        pmix_output_verbose(2, pmix_server_globals.get_output, "%s:%d NSPACE %s not all registered",
-                            pmix_globals.myid.nspace, pmix_globals.myid.rank, nspace);
-        rc = defer_response(nspace, rank, cd, localonly, cbfunc, cbdata, &tv, &lcd);
+        pmix_output_verbose(2, pmix_server_globals.get_output,
+                           "%s:%d NSPACE %s not all registered - delay %d",
+                            pmix_globals.myid.nspace, pmix_globals.myid.rank,
+                            nspace, (int)tv.tv_sec);
+        rc = defer_response(nspace, rank, key, cd, localonly, cbfunc, cbdata, &tv, &lcd);
         if (PMIX_ERR_NOT_FOUND == rc) {
             /* just means we created a tracker */
             rc = PMIX_SUCCESS;
@@ -424,7 +435,7 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
                 if (rank == iptr->pname.rank) {
                     if (0 > iptr->peerid) {
                         /* this rank has not connected yet, so this request needs to be held */
-                        rc = defer_response(nspace, rank, cd, localonly, cbfunc, cbdata, &tv, &lcd);
+                        rc = defer_response(nspace, rank, key, cd, localonly, cbfunc, cbdata, &tv, &lcd);
                         if (PMIX_ERR_NOT_FOUND == rc) {
                             /* just means we created a tracker */
                             rc = PMIX_SUCCESS;
@@ -518,7 +529,7 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
                 if (0 == tv.tv_sec) {
                     tv.tv_sec = 2;
                 }
-                rc = defer_response(nspace, rank, cd, localonly, cbfunc, cbdata, &tv, &lcd);
+                rc = defer_response(nspace, rank, key, cd, localonly, cbfunc, cbdata, &tv, &lcd);
                 if (PMIX_ERR_NOT_FOUND == rc) {
                     /* just means we created a tracker */
                     rc = PMIX_SUCCESS;
@@ -561,7 +572,7 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
     }
 
     /* since everyone has registered, see if we already have this data */
-    rc = _satisfy_request(nptr, rank, cd, diffnspace, scope, cbfunc, cbdata);
+    rc = _satisfy_request(nptr, rank, key, cd, diffnspace, scope, cbfunc, cbdata);
     if (PMIX_SUCCESS == rc) {
         /* return success as the satisfy_request function
          * calls the cbfunc for us, and it will have
@@ -569,14 +580,15 @@ pmix_status_t pmix_server_get(pmix_buffer_t *buf, pmix_modex_cbfunc_t cbfunc, vo
         return PMIX_SUCCESS;
     }
 
-    pmix_output_verbose(2, pmix_server_globals.get_output, "%s:%d DATA NOT FOUND",
+    pmix_output_verbose(2, pmix_server_globals.get_output,
+                        "%s:%d DATA NOT FOUND",
                         pmix_globals.myid.nspace, pmix_globals.myid.rank);
 
 request:
     /* setup to handle this remote request, but don't set any timeout as
      * this might create a race condition with our host if they also
      * support the timeout */
-    rc = defer_response(nspace, rank, cd, localonly, cbfunc, cbdata, NULL, &lcd);
+    rc = defer_response(nspace, rank, key, cd, localonly, cbfunc, cbdata, NULL, &lcd);
     if (PMIX_SUCCESS == rc) {
         /* we are already waiting for the data - nothing more
          * for us to do as the function added the new request
@@ -631,8 +643,9 @@ request:
     return rc;
 }
 
-static pmix_status_t create_local_tracker(char nspace[], pmix_rank_t rank, pmix_info_t info[],
-                                          size_t ninfo, pmix_modex_cbfunc_t cbfunc, void *cbdata,
+static pmix_status_t create_local_tracker(char nspace[], pmix_rank_t rank, char *key,
+                                          pmix_info_t info[], size_t ninfo,
+                                          pmix_modex_cbfunc_t cbfunc, void *cbdata,
                                           pmix_dmdx_local_t **ld, pmix_dmdx_request_t **rq)
 {
     pmix_dmdx_local_t *lcd, *cd;
@@ -686,6 +699,9 @@ complete:
         *ld = lcd;
         return PMIX_ERR_NOMEM;
     }
+    if (NULL != key) {
+        req->key = strdup(key);
+    }
     PMIX_RETAIN(lcd);
     req->lcd = lcd;
     req->cbfunc = cbfunc;
@@ -719,10 +735,15 @@ void pmix_pending_nspace_requests(pmix_namespace_t *nptr)
             continue;
         }
 
-        PMIX_LIST_FOREACH (info, &nptr->ranks, pmix_rank_info_t) {
-            if (info->pname.rank == cd->proc.rank) {
-                found = true; // we will satisy this request upon commit from new proc
-                break;
+        /*  If they asked for job level data, then the data was just registered */
+        if(cd->proc.rank == PMIX_RANK_WILDCARD){
+            found = true;
+        }else{
+            PMIX_LIST_FOREACH (info, &nptr->ranks, pmix_rank_info_t) {
+                if (info->pname.rank == cd->proc.rank) {
+                    found = true; // we will satisy this request upon commit from new proc
+                    break;
+                }
             }
         }
 
@@ -815,26 +836,24 @@ static pmix_status_t get_job_data(char *nspace,
     return PMIX_SUCCESS;
 }
 
-static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
+static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank, char *key,
                                       pmix_server_caddy_t *cd, bool diffnspace, pmix_scope_t scope,
                                       pmix_modex_cbfunc_t cbfunc, void *cbdata)
 {
     pmix_status_t rc;
     bool found = false;
-    bool used_mypeer = true;
     pmix_buffer_t pbkt, pkt;
     pmix_proc_t proc;
     pmix_cb_t cb;
     pmix_byte_object_t bo;
     char *data = NULL;
     size_t sz = 0;
-    pmix_rank_info_t *rinfo;
-    pmix_peer_t *peer;
 
     pmix_output_verbose(2, pmix_server_globals.get_output,
-                        "%s:%d SATISFY REQUEST CALLED FOR %s:%d ON SCOPE %s",
+                        "%s:%d SATISFY REQUEST CALLED FOR %s:%d ON SCOPE %s KEY %s",
                         pmix_globals.myid.nspace, pmix_globals.myid.rank,
-                        nptr->nspace, rank, PMIx_Scope_string(scope));
+                        nptr->nspace, rank, PMIx_Scope_string(scope),
+                        (NULL == key) ? "NULL" : key);
 
     PMIX_CONSTRUCT(&pbkt, pmix_buffer_t);
     PMIX_LOAD_NSPACE(proc.nspace, nptr->nspace);
@@ -847,35 +866,38 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
             PMIX_DESTRUCT(&pbkt);
             return rc;
         }
+        if (PMIX_RANK_WILDCARD == rank) {
+            // we are done
+            found = true;
+            goto complete;
+        }
     }
 
-    /* retrieve the data for the specific rank they are asking about */
     proc.rank = rank;
     PMIX_CONSTRUCT(&cb, pmix_cb_t);
-    /* this is a local request, so give the gds the option
-     * of returning a copy of the data, or a pointer to
-     * local storage */
+
+    /* if they are asking for a reserved key, we only look for
+     * that one specific key. If they are looking for a
+     * non-reserved key - return all non-reserved keys for the
+     * specified proc. We do this as an optimization as we
+     * suspect that a request for one value for a proc will be
+     * followed by requests for additional values
+     */
+
+    if (NULL != key && PMIX_CHECK_RESERVED_KEY(key)) {
+        cb.key = key;
+    }
+
     cb.proc = &proc;
     cb.scope = scope;
-    cb.copy = false;
     cb.info = cd->info;
     cb.ninfo = cd->ninfo;
     PMIX_GDS_FETCH_KV(rc, pmix_globals.mypeer, &cb);
-    /* if we didn't find it on my peer, it could have
-     * been stored on their peer - so check there */
+    /* if we didn't find it on my peer, then it isn't found */
     if (PMIX_SUCCESS != rc) {
-        /* all procs in a given nspace must use
-         * the same GDS component */
-        peer = NULL;
-        rinfo = (pmix_rank_info_t*)pmix_list_get_first(&nptr->ranks);
-        while (NULL == peer && NULL != rinfo) {
-            peer = (pmix_peer_t*)pmix_pointer_array_get_item(&pmix_server_globals.clients, rinfo->peerid);
-            rinfo = (pmix_rank_info_t*)pmix_list_get_next(&rinfo->super);
-        }
-        if (NULL != peer) {
-            PMIX_GDS_FETCH_KV(rc, peer, &cb);
-            used_mypeer = false;
-        }
+        PMIX_DESTRUCT(&pbkt);
+        PMIX_DESTRUCT(&cb);
+        return PMIX_ERR_NOT_FOUND;
     }
     cb.info = NULL;
     cb.ninfo = 0;
@@ -883,7 +905,7 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
         found = true;
         PMIX_CONSTRUCT(&pkt, pmix_buffer_t);
         /* assemble the provided data into a byte object */
-        if (PMIX_RANK_UNDEF == rank || diffnspace || used_mypeer) {
+        if (PMIX_RANK_UNDEF == rank || diffnspace) {
             PMIX_GDS_ASSEMB_KVS_REQ(rc, pmix_globals.mypeer, &proc, &cb.kvs, &pkt, cd);
         } else {
             PMIX_GDS_ASSEMB_KVS_REQ(rc, cd->peer, &proc, &cb.kvs, &pkt, cd);
@@ -919,14 +941,12 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
             }
             PMIX_DESTRUCT(&pkt);
         } else {
-            // Don't unload the buffer here. Since
-            // it gets repacked, we'll lose the base_ptr
-            // to destroy pkt later.
-            bo.bytes = (char *) pkt.unpack_ptr;
-            bo.size = pkt.bytes_used;
+            PMIX_UNLOAD_BUFFER(&pkt, bo.bytes, bo.size);
+            PMIX_DESTRUCT(&pkt);
 
             /* pack it for transmission */
             PMIX_BFROPS_PACK(rc, cd->peer, &pbkt, &bo, 1, PMIX_BYTE_OBJECT);
+            PMIX_BYTE_OBJECT_DESTRUCT(&bo); // data has been copied
             if (PMIX_SUCCESS != rc) {
                 PMIX_ERROR_LOG(rc);
                 PMIX_DESTRUCT(&pbkt);
@@ -937,20 +957,78 @@ static pmix_status_t _satisfy_request(pmix_namespace_t *nptr, pmix_rank_t rank,
     }
     PMIX_DESTRUCT(&cb);
 
+complete:
     PMIX_UNLOAD_BUFFER(&pbkt, data, sz);
     PMIX_DESTRUCT(&pbkt);
 
     if (found) {
         /* pass it back */
         cbfunc(rc, data, sz, cbdata, relfn, data);
-        // Safe to free pkt.
-        PMIX_DESTRUCT(&pkt);
         return rc;
     }
 
     return PMIX_ERR_NOT_FOUND;
 }
 
+static void check_req(pmix_namespace_t *nptr,
+                      pmix_rank_t rank,
+                      pmix_status_t status,
+                      pmix_scope_t scope,
+                      pmix_dmdx_local_t *ptr)
+{
+    pmix_dmdx_request_t *req, *rnext;
+    pmix_server_caddy_t scd;
+    bool diffnspace;
+    pmix_status_t rc;
+    char *key;
+
+    /* if there are no local reqs on this request (e.g., only
+     * one proc requested it and that proc has died), then
+     * just remove the request */
+    if (0 == pmix_list_get_size(&ptr->loc_reqs)) {
+        return;
+    }
+
+    /* somebody was interested in this rank */
+    if (PMIX_SUCCESS != status) {
+        /* if we've got an error for this request - just forward it*/
+        PMIX_LIST_FOREACH_SAFE(req, rnext, &ptr->loc_reqs, pmix_dmdx_request_t) {
+            req->cbfunc(status, NULL, 0, req->cbdata, NULL, NULL);
+            pmix_list_remove_item(&ptr->loc_reqs, &req->super);
+            PMIX_RELEASE(req);
+        }
+    } else {
+        /* if we've got the blob - try to satisfy requests */
+        /* run through all the requests for this rank */
+        /* this info is going back to one of our peers, so provide a server
+         * caddy with our peer in it so the data gets packed correctly */
+        PMIX_CONSTRUCT(&scd, pmix_server_caddy_t);
+        PMIX_RETAIN(pmix_globals.mypeer);
+        scd.peer = pmix_globals.mypeer;
+        PMIX_LIST_FOREACH_SAFE(req, rnext, &ptr->loc_reqs, pmix_dmdx_request_t) {
+            diffnspace = !PMIX_CHECK_NSPACE(nptr->nspace, req->lcd->proc.nspace);
+            // if the rank is undef, then only ask for the one key - otherwise,
+            // return all keys for that rank. This is an optimization as we
+            // assume if someone asked for one key for a specific rank, they
+            // are likely to ask for more of them
+            if (PMIX_RANK_UNDEF == rank) {
+                key = req->key;
+            } else {
+                key = NULL;
+            }
+           rc = _satisfy_request(nptr, rank, key, &scd, diffnspace, scope,
+                                  req->cbfunc, req->cbdata);
+            if (PMIX_SUCCESS != rc) {
+                /* if we can't satisfy this particular request (missing key?) */
+                req->cbfunc(rc, NULL, 0, req->cbdata, NULL, NULL);
+            }
+            pmix_list_remove_item(&ptr->loc_reqs, &req->super);
+            PMIX_RELEASE(req);
+        }
+        PMIX_DESTRUCT(&scd);
+    }
+}
+
 /* Resolve pending requests to this namespace/rank */
 pmix_status_t pmix_pending_resolve(pmix_namespace_t *nptr,
                                    pmix_rank_t rank,
@@ -958,78 +1036,31 @@ pmix_status_t pmix_pending_resolve(pmix_namespace_t *nptr,
                                    pmix_scope_t scope,
                                    pmix_dmdx_local_t *lcd)
 {
-    pmix_dmdx_local_t *cd, *ptr;
-    pmix_dmdx_request_t *req, *rnext;
-    pmix_server_caddy_t scd;
+    pmix_dmdx_local_t *cd, *cdnext;
 
     /* find corresponding request (if exists) */
     if (NULL == lcd) {
-        ptr = NULL;
-        if (NULL != nptr) {
-            PMIX_LIST_FOREACH (cd, &pmix_server_globals.local_reqs, pmix_dmdx_local_t) {
-                if (!PMIX_CHECK_NSPACE(nptr->nspace, cd->proc.nspace) || rank != cd->proc.rank) {
-                    continue;
-                }
-                ptr = cd;
-                break;
+        PMIX_LIST_FOREACH_SAFE(cd, cdnext, &pmix_server_globals.local_reqs, pmix_dmdx_local_t) {
+            if (!PMIX_CHECK_NSPACE(nptr->nspace, cd->proc.nspace) ) {
+                continue;
+            }
+            if (PMIX_RANK_UNDEF == cd->proc.rank ||
+                rank == cd->proc.rank) {
+                check_req(nptr, cd->proc.rank, status, scope, cd);
+            }
+            if (0 == pmix_list_get_size(&cd->loc_reqs)) {
+                pmix_list_remove_item(&pmix_server_globals.local_reqs, &cd->super);
+                PMIX_RELEASE(cd);
             }
-        }
-        if (NULL == ptr) {
-            return PMIX_SUCCESS;
         }
     } else {
-        ptr = lcd;
-    }
-
-    /* if there are no local reqs on this request (e.g., only
-     * one proc requested it and that proc has died), then
-     * just remove the request */
-    if (0 == pmix_list_get_size(&ptr->loc_reqs)) {
-        goto cleanup;
-    }
-
-    /* somebody was interested in this rank */
-    if (PMIX_SUCCESS != status) {
-        /* if we've got an error for this request - just forward it*/
-        PMIX_LIST_FOREACH (req, &ptr->loc_reqs, pmix_dmdx_request_t) {
-            req->cbfunc(status, NULL, 0, req->cbdata, NULL, NULL);
+        check_req(nptr, rank, status, scope, lcd);
+        if (0 == pmix_list_get_size(&lcd->loc_reqs)) {
+            pmix_list_remove_item(&pmix_server_globals.local_reqs, &lcd->super);
+            PMIX_RELEASE(lcd);
         }
-    } else if (NULL != nptr) {
-        /* if we've got the blob - try to satisfy requests */
-        /* run through all the requests for this rank */
-        /* this info is going back to one of our peers, so provide a server
-         * caddy with our peer in it so the data gets packed correctly */
-        PMIX_CONSTRUCT(&scd, pmix_server_caddy_t);
-        PMIX_RETAIN(pmix_globals.mypeer);
-        scd.peer = pmix_globals.mypeer;
-        PMIX_LIST_FOREACH (req, &ptr->loc_reqs, pmix_dmdx_request_t) {
-            pmix_status_t rc;
-            bool diffnspace = !PMIX_CHECK_NSPACE(nptr->nspace, req->lcd->proc.nspace);
-            rc = _satisfy_request(nptr, rank, &scd, diffnspace, scope,
-                                  req->cbfunc, req->cbdata);
-            if (PMIX_SUCCESS != rc) {
-                /* if we can't satisfy this particular request (missing key?) */
-                req->cbfunc(rc, NULL, 0, req->cbdata, NULL, NULL);
-            }
-        }
-        PMIX_DESTRUCT(&scd);
     }
 
-cleanup:
-    /* remove all requests to this rank and cleanup the corresponding structure */
-    pmix_list_remove_item(&pmix_server_globals.local_reqs, &ptr->super);
-    /* the dmdx request is linked back to its local request for ease
-     * of lookup upon return from the server. However, this means that
-     * the refcount of the local request has been increased by the number
-     * dmdx requests attached to it. In order to release the local request's
-     * storage, we first have to drive the refcount down by releasing all
-     * of the associated dmdx requests */
-    PMIX_LIST_FOREACH_SAFE (req, rnext, &ptr->loc_reqs, pmix_dmdx_request_t) {
-        pmix_list_remove_item(&ptr->loc_reqs, &req->super);
-        PMIX_RELEASE(req); // decrements refcount of ptr
-    }
-    PMIX_RELEASE(ptr);
-
     return PMIX_SUCCESS;
 }
 
