@@ -3,7 +3,7 @@
  * Copyright (c) 2015-2020 Intel, Inc.  All rights reserved.
  * Copyright (c) 2020      IBM Corporation.  All rights reserved.
  * Copyright (c) 2020      Cisco Systems, Inc.  All rights reserved
- * Copyright (c) 2021-2023 Nanook Consulting.  All rights reserved.
+ * Copyright (c) 2021-2024 Nanook Consulting  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -21,6 +21,7 @@
 #include "src/include/pmix_frameworks.h"
 #include "src/include/prte_frameworks.h"
 #include "src/mca/errmgr/errmgr.h"
+#include "src/mca/pmdl/base/base.h"
 #include "src/mca/schizo/base/base.h"
 #include "src/runtime/prte_globals.h"
 #include "src/util/pmix_argv.h"
@@ -242,29 +243,9 @@ char *prte_schizo_base_strip_quotes(char *p)
     return pout;
 }
 
-bool prte_schizo_base_check_prte_param(char *param)
-{
-    char *p;
-    size_t n;
-    int len;
-
-    p = strchr(param, '_');
-    len = (int)(p - param);
-
-    if (0 == strncmp(param, "prte", len)) {
-        return true;
-    }
-    for (n=0; NULL != prte_framework_names[n]; n++) {
-        if (0 == strncmp(param, prte_framework_names[n], len)) {
-            return true;
-        }
-    }
-    return false;
-}
-
 int prte_schizo_base_parse_prte(int argc, int start, char **argv, char ***target)
 {
-    int i, j;
+    int i;
     bool use;
     char *p1, *p2, *param;
 
@@ -312,7 +293,7 @@ int prte_schizo_base_parse_prte(int argc, int start, char **argv, char ***target
 
             /* this is a generic MCA designation, so see if the parameter it
              * refers to belongs to one of our frameworks */
-            use = prte_schizo_base_check_prte_param(p1);
+            use = pmix_pmdl_base_check_prte_param(p1);
             if (use) {
                 /* replace the generic directive with a PRRTE specific
                  * one so we know this has been processed */
@@ -361,54 +342,9 @@ int prte_schizo_base_parse_prte(int argc, int start, char **argv, char ***target
     return PRTE_SUCCESS;
 }
 
-static char **pmix_frameworks_tocheck = pmix_framework_names;
-static bool pmix_frameworks_setup = false;
-
-static void setup_pmix_frameworks(void)
-{
-    if (pmix_frameworks_setup) {
-        return;
-    }
-    pmix_frameworks_setup = true;
-
-    char *env = getenv("PMIX_MCA_PREFIXES");
-    if (NULL == env) {
-        return;
-    }
-
-    // If we found the env variable, it will be a comma-delimited list
-    // of values.  Split it into an argv-style array.
-    char **tmp = PMIX_ARGV_SPLIT_COMPAT(env, ',');
-    if (NULL != tmp) {
-        pmix_frameworks_tocheck = tmp;
-    }
-}
-
-bool prte_schizo_base_check_pmix_param(char *param)
-{
-    char *p;
-    size_t n;
-    int len;
-
-    setup_pmix_frameworks();
-
-    p = strchr(param, '_');
-    len = (int)(p - param);
-
-    if (0 == strncmp(param, "pmix", len)) {
-        return true;
-    }
-    for (n=0; NULL != pmix_frameworks_tocheck[n]; n++) {
-        if (0 == strncmp(param, pmix_frameworks_tocheck[n], len)) {
-            return true;
-        }
-    }
-    return false;
-}
-
 int prte_schizo_base_parse_pmix(int argc, int start, char **argv, char ***target)
 {
-    int i, j;
+    int i;
     bool use;
     char *p1, *p2, *param;
 
@@ -487,7 +423,7 @@ int prte_schizo_base_parse_pmix(int argc, int start, char **argv, char ***target
 
             /* this is a generic MCA designation, so see if the parameter it
              * refers to belongs to one of our frameworks */
-            use = prte_schizo_base_check_pmix_param(p1);
+            use = pmix_pmdl_base_check_pmix_param(p1);
             if (use) {
                 /* replace the generic directive with a PMIx specific
                  * one so we know this has been processed */
