@@ -220,6 +220,9 @@ typedef uint16_t prte_job_flags_t;
                                                                        //         are to be displayed
 #define PRTE_JOB_DISPLAY_PARSEABLE_OUTPUT   (PRTE_JOB_START_KEY + 110) // bool - display output in machine parsable format
 #define PRTE_JOB_EXTEND_DVM                 (PRTE_JOB_START_KEY + 111) // bool - DVM is being extended
+#define PRTE_JOB_CHILD_SEP                  (PRTE_JOB_START_KEY + 116) // bool - child job is to be considered independent
+                                                                       //        from its parent, do not terminate if
+                                                                       //        parent dies first
 
 #define PRTE_JOB_MAX_KEY (PRTE_JOB_START_KEY + 200)
 
@@ -325,3 +328,12 @@ PRTE_EXPORT int prte_attr_register(const char *project, prte_attribute_key_t key
         free(_output);                                                              \
     } while (0)
 #endif
+
+// forward declarations
+struct prte_proc_t;
+struct prte_node_t;
+struct prte_job_t;
+
+PRTE_EXPORT char* prte_print_proc_flags(struct prte_proc_t *p);
+PRTE_EXPORT char* prte_print_node_flags(struct prte_node_t *p);
+PRTE_EXPORT char* prte_print_job_flags(struct prte_job_t *p);
