@@ -9,8 +9,8 @@
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
- * Copyright (c) 2008-2014 University of Houston. All rights reserved.
- * Copyright (c) 2015      Research Organization for Information Science
+ * Copyright (c) 2008-2022 University of Houston. All rights reserved.
+ * Copyright (c) 2015-2018 Research Organization for Information Science
  *                         and Technology (RIST). All rights reserved.
  * $COPYRIGHT$
  *
@@ -28,7 +28,7 @@
 #include "ompi/mca/mca.h"
 #include "ompi/mca/fcoll/fcoll.h"
 #include "ompi/mca/fcoll/base/base.h"
-#include "ompi/mca/io/ompio/io_ompio.h"
+#include "ompi/mca/common/ompio/common_ompio.h"
 
 BEGIN_C_DECLS
 
@@ -36,33 +36,32 @@ BEGIN_C_DECLS
 
 extern int mca_fcoll_dynamic_priority;
 
-OMPI_MODULE_DECLSPEC extern mca_fcoll_base_component_2_0_0_t mca_fcoll_dynamic_component;
+OMPI_DECLSPEC extern mca_fcoll_base_component_2_0_0_t mca_fcoll_dynamic_component;
 
 /* API functions */
 
 int mca_fcoll_dynamic_component_init_query(bool enable_progress_threads,
                                            bool enable_mpi_threads);
 struct mca_fcoll_base_module_1_0_0_t *
-mca_fcoll_dynamic_component_file_query (mca_io_ompio_file_t *fh, int *priority);
+mca_fcoll_dynamic_component_file_query (ompio_file_t *fh, int *priority);
 
-int mca_fcoll_dynamic_component_file_unquery (mca_io_ompio_file_t *file);
+int mca_fcoll_dynamic_component_file_unquery (ompio_file_t *file);
 
-int mca_fcoll_dynamic_module_init (mca_io_ompio_file_t *file);
-int mca_fcoll_dynamic_module_finalize (mca_io_ompio_file_t *file);
+int mca_fcoll_dynamic_module_init (ompio_file_t *file);
+int mca_fcoll_dynamic_module_finalize (ompio_file_t *file);
 
-int mca_fcoll_dynamic_file_read_all (mca_io_ompio_file_t *fh,
+int mca_fcoll_dynamic_file_write_all (struct ompio_file_t *fh,
+                                      const void *buf,
+                                      int count,
+                                      struct ompi_datatype_t *datatype,
+                                      ompi_status_public_t * status);
+int mca_fcoll_dynamic_file_read_all (struct ompio_file_t *fh,
                                      void *buf,
                                      int count,
                                      struct ompi_datatype_t *datatype,
                                      ompi_status_public_t * status);
 
 
-int mca_fcoll_dynamic_file_write_all (mca_io_ompio_file_t *fh,
-                                      const void *buf,
-                                      int count,
-                                      struct ompi_datatype_t *datatype,
-                                      ompi_status_public_t * status);
-
 
 END_C_DECLS
 
