@@ -1,18 +1,23 @@
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil -*- */
 /*
  * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2005 The University of Tennessee and The University
+ * Copyright (c) 2004-2020 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
- * Copyright (c) 2004-2008 High Performance Computing Center Stuttgart, 
+ * Copyright (c) 2004-2008 High Performance Computing Center Stuttgart,
  *                         University of Stuttgart.  All rights reserved.
  * Copyright (c) 2004-2005 The Regents of the University of California.
  *                         All rights reserved.
+ * Copyright (c) 2013      Los Alamos National Security, LLC.  All rights
+ *                         reserved.
+ * Copyright (c) 2015      Research Organization for Information Science
+ *                         and Technology (RIST). All rights reserved.
  * $COPYRIGHT$
- * 
+ *
  * Additional copyrights may follow
- * 
+ *
  * $HEADER$
  */
 
@@ -25,21 +30,20 @@
 #include "ompi/datatype/ompi_datatype.h"
 #include "ompi/memchecker.h"
 
-#if OPAL_HAVE_WEAK_SYMBOLS && OMPI_PROFILING_DEFINES
+#if OMPI_BUILD_MPI_PROFILING
+#if OPAL_HAVE_WEAK_SYMBOLS
 #pragma weak MPI_Type_create_struct = PMPI_Type_create_struct
 #endif
-
-#if OMPI_PROFILING_DEFINES
-#include "ompi/mpi/c/profile/defines.h"
+#define MPI_Type_create_struct PMPI_Type_create_struct
 #endif
 
 static const char FUNC_NAME[] = "MPI_Type_create_struct";
 
 
 int MPI_Type_create_struct(int count,
-                           int array_of_blocklengths[],
-                           MPI_Aint array_of_displacements[],
-                           MPI_Datatype array_of_types[],
+                           const int array_of_blocklengths[],
+                           const MPI_Aint array_of_displacements[],
+                           const MPI_Datatype array_of_types[],
                            MPI_Datatype *newtype)
 {
     int i, rc;
@@ -48,53 +52,48 @@ int MPI_Type_create_struct(int count,
         for ( i = 0; i < count; i++ ) {
             MEMCHECKER(
                 memchecker_datatype(array_of_types[i]);
-            );
+                );
         }
     }
-    
+
     if( MPI_PARAM_CHECK ) {
         OMPI_ERR_INIT_FINALIZE(FUNC_NAME);
         if( count < 0 ) {
-            return OMPI_ERRHANDLER_INVOKE(MPI_COMM_WORLD, MPI_ERR_COUNT,
+            return OMPI_ERRHANDLER_NOHANDLE_INVOKE(MPI_ERR_COUNT,
                                           FUNC_NAME);
         } else if( (count > 0) && (NULL == array_of_blocklengths ||
                                    NULL == array_of_displacements ||
                                    NULL == array_of_types) ) {
-            return OMPI_ERRHANDLER_INVOKE(MPI_COMM_WORLD, MPI_ERR_ARG, FUNC_NAME);
+            return OMPI_ERRHANDLER_NOHANDLE_INVOKE(MPI_ERR_ARG, FUNC_NAME);
         } else if (NULL == newtype) {
-            return OMPI_ERRHANDLER_INVOKE(MPI_COMM_WORLD, MPI_ERR_TYPE, FUNC_NAME);
+            return OMPI_ERRHANDLER_NOHANDLE_INVOKE(MPI_ERR_TYPE, FUNC_NAME);
         }
         for ( i = 0; i < count; i++ ){
             if (NULL == array_of_types[i] ||
                 MPI_DATATYPE_NULL == array_of_types[i]) {
-                return OMPI_ERRHANDLER_INVOKE(MPI_COMM_WORLD, MPI_ERR_TYPE,
+                return OMPI_ERRHANDLER_NOHANDLE_INVOKE(MPI_ERR_TYPE,
                                               FUNC_NAME);
             } else if (array_of_blocklengths[i] < 0) {
-                return OMPI_ERRHANDLER_INVOKE(MPI_COMM_WORLD, MPI_ERR_ARG,
+                return OMPI_ERRHANDLER_NOHANDLE_INVOKE(MPI_ERR_ARG,
                                               FUNC_NAME);
             }
         }
     }
 
-    OPAL_CR_ENTER_LIBRARY();
-
     rc = ompi_datatype_create_struct( count, array_of_blocklengths, array_of_displacements,
-                                 array_of_types, newtype );
+                                      array_of_types, newtype );
     if( rc != MPI_SUCCESS ) {
         ompi_datatype_destroy( newtype );
-        OMPI_ERRHANDLER_RETURN( rc, MPI_COMM_WORLD,
+        OMPI_ERRHANDLER_NOHANDLE_RETURN( rc, 
                                 rc, FUNC_NAME );
     }
-   
-    {
-        int* a_i[2];
 
-        a_i[0] = &count;
-        a_i[1] = array_of_blocklengths;
+    {
+        const int* a_i[2] = {&count, array_of_blocklengths};
+
         ompi_datatype_set_args( *newtype, count + 1, a_i, count, array_of_displacements,
-                           count, array_of_types, MPI_COMBINER_STRUCT );
+                                count, array_of_types, MPI_COMBINER_STRUCT );
     }
 
-    OPAL_CR_EXIT_LIBRARY();
     return MPI_SUCCESS;
 }
