@@ -26,8 +26,6 @@
 #include "ompi/request/request_default.h"
 #include "ompi/request/grequest.h"
 
-#include "ompi/mca/crcp/crcp.h"
-
 int ompi_request_default_test(ompi_request_t ** rptr,
                               int *completed,
                               ompi_status_public_t * status )
@@ -37,7 +35,7 @@ int ompi_request_default_test(ompi_request_t ** rptr,
 #if OPAL_ENABLE_PROGRESS_THREADS == 0
     int do_it_once = 0;
 
- recheck_request_status:
+recheck_request_status:
 #endif
     opal_atomic_mb();
     if( request->req_state == OMPI_REQUEST_INACTIVE ) {
@@ -49,12 +47,6 @@ int ompi_request_default_test(ompi_request_t ** rptr,
     }
 
     if( REQUEST_COMPLETE(request) ) {
-#if OPAL_ENABLE_FT_CR == 1
-        if( opal_cr_is_enabled) {
-            OMPI_CRCP_REQUEST_COMPLETE(request);
-        }
-#endif
-
         *completed = true;
         /* For a generalized request, we *have* to call the query_fn
            if it completes, even if the user provided
@@ -79,15 +71,25 @@ int ompi_request_default_test(ompi_request_t ** rptr,
            later! */
         return ompi_request_free(rptr);
     }
+#if OPAL_ENABLE_FT_MPI
+    /* Check for dead requests due to process failure */
+    /* Special case for MPI_ANY_SOURCE */
+    if(OPAL_UNLIKELY( ompi_request_is_failed(request) &&
+                      MPI_ERR_PROC_FAILED_PENDING == request->req_status.MPI_ERROR )) {
+        *completed = false;
+        return MPI_ERR_PROC_FAILED_PENDING;
+    }
+#endif
 #if OPAL_ENABLE_PROGRESS_THREADS == 0
     if( 0 == do_it_once ) {
         /**
          * If we run the opal_progress then check the status of the request before
          * leaving. We will call the opal_progress only once per call.
          */
-        opal_progress();
-        do_it_once++;
-        goto recheck_request_status;
+        ++do_it_once;
+        if (0 != opal_progress()) {
+            goto recheck_request_status;
+        }
     }
 #endif
     *completed = false;
@@ -116,12 +118,6 @@ int ompi_request_default_test_any(
         }
 
         if( REQUEST_COMPLETE(request) ) {
-#if OPAL_ENABLE_FT_CR == 1
-            if( opal_cr_is_enabled) {
-                OMPI_CRCP_REQUEST_COMPLETE(request);
-            }
-#endif
-
             *index = i;
             *completed = true;
             /* MPI 2:8.2 says that generalized requests always have
@@ -149,6 +145,16 @@ int ompi_request_default_test_any(
                will happen later! */
             return ompi_request_free(rptr);
         }
+#if OPAL_ENABLE_FT_MPI
+        /* Check for dead requests due to process failure */
+        /* Special case for MPI_ANY_SOURCE */
+        if(OPAL_UNLIKELY( ompi_request_is_failed(request) &&
+                          MPI_ERR_PROC_FAILED_PENDING == request->req_status.MPI_ERROR )) {
+            *index = i;
+            *completed = false;
+            return MPI_ERR_PROC_FAILED_PENDING;
+        }
+#endif /* OPAL_ENABLE_FT_MPI */
     }
 
     /* Only fall through here if we found nothing */
@@ -178,23 +184,45 @@ int ompi_request_default_test_all(
     ompi_request_t **rptr;
     size_t num_completed = 0;
     ompi_request_t *request;
+    int do_it_once = 0;
 
     opal_atomic_mb();
-    rptr = requests;
-    for (i = 0; i < count; i++, rptr++) {
-        request = *rptr;
+    for (i = 0; i < count; i++) {
+        request = requests[i];
 
-        if( request->req_state == OMPI_REQUEST_INACTIVE ||
-            REQUEST_COMPLETE(request) ) {
+        if( request->req_state == OMPI_REQUEST_INACTIVE || REQUEST_COMPLETE(request) ) {
             num_completed++;
+            continue;
         }
+#if OPAL_ENABLE_FT_MPI
+        /* Check for dead requests due to process failure */
+        /* Special case for MPI_ANY_SOURCE */
+        if(OPAL_UNLIKELY( ompi_request_is_failed(request) &&
+                          MPI_ERR_PROC_FAILED_PENDING == request->req_status.MPI_ERROR )) {
+            if (MPI_STATUSES_IGNORE != statuses) {
+                OMPI_COPY_STATUS(&statuses[i], request->req_status, true);
+                statuses[i].MPI_ERROR = MPI_ERR_PROC_FAILED_PENDING;
+            }
+            *completed = false;
+            return MPI_ERR_PROC_FAILED_PENDING;
+        }
+#endif /* OPAL_ENABLE_FT_MPI */
+#if OPAL_ENABLE_PROGRESS_THREADS == 0
+        if (0 == do_it_once) {
+            ++do_it_once;
+            if (0 != opal_progress()) {
+                /* continue walking the list, retest the current request */
+                --i;
+                continue;
+            }
+        }
+#endif /* OPAL_ENABLE_PROGRESS_THREADS */
+        /* short-circuit */
+        break;
     }
 
     if (num_completed != count) {
         *completed = false;
-#if OPAL_ENABLE_PROGRESS_THREADS == 0
-        opal_progress();
-#endif
         return OMPI_SUCCESS;
     }
 
@@ -216,11 +244,6 @@ int ompi_request_default_test_all(
             if (OMPI_REQUEST_GEN == request->req_type) {
                 ompi_grequest_invoke_query(request, &request->req_status);
             }
-#if OPAL_ENABLE_FT_CR == 1
-            if( opal_cr_is_enabled) {
-                OMPI_CRCP_REQUEST_COMPLETE(request);
-            }
-#endif
             OMPI_COPY_STATUS(&statuses[i], request->req_status, true);
             if( request->req_persistent ) {
                 request->req_state = OMPI_REQUEST_INACTIVE;
@@ -236,6 +259,12 @@ int ompi_request_default_test_all(
                 }
             } else {
                 rc = MPI_ERR_IN_STATUS;
+#if OPAL_ENABLE_FT_MPI
+                if (MPI_ERR_PROC_FAILED == request->req_status.MPI_ERROR
+                 || MPI_ERR_REVOKED == request->req_status.MPI_ERROR) {
+                    rc = request->req_status.MPI_ERROR;
+                }
+#endif /* OPAL_ENABLE_FT_MPI */
             }
         }
     } else {
@@ -251,11 +280,6 @@ int ompi_request_default_test_all(
             if (OMPI_REQUEST_GEN == request->req_type) {
                 ompi_grequest_invoke_query(request, &request->req_status);
             }
-#if OPAL_ENABLE_FT_CR == 1
-            if( opal_cr_is_enabled) {
-                OMPI_CRCP_REQUEST_COMPLETE(request);
-            }
-#endif
             if( request->req_persistent ) {
                 request->req_state = OMPI_REQUEST_INACTIVE;
                 continue;
@@ -268,6 +292,12 @@ int ompi_request_default_test_all(
                 }
             } else {
                 rc = MPI_ERR_IN_STATUS;
+#if OPAL_ENABLE_FT_MPI
+                if (MPI_ERR_PROC_FAILED == request->req_status.MPI_ERROR
+                 || MPI_ERR_REVOKED == request->req_status.MPI_ERROR) {
+                    rc = request->req_status.MPI_ERROR;
+                }
+#endif /* OPAL_ENABLE_FT_MPI */
             }
         }
     }
@@ -297,13 +327,17 @@ int ompi_request_default_test_some(
             continue;
         }
         if( REQUEST_COMPLETE(request) ) {
-#if OPAL_ENABLE_FT_CR == 1
-            if( opal_cr_is_enabled) {
-                OMPI_CRCP_REQUEST_COMPLETE(request);
-            }
-#endif
+            indices[num_requests_done++] = i;
+            continue;
+        }
+#if OPAL_ENABLE_FT_MPI
+        /* Check for dead requests due to process failure */
+        /* Special case for MPI_ANY_SOURCE - Error managed below */
+        if(OPAL_UNLIKELY( ompi_request_is_failed(request) &&
+                          MPI_ERR_PROC_FAILED_PENDING == request->req_status.MPI_ERROR )) {
             indices[num_requests_done++] = i;
         }
+#endif /* OPAL_ENABLE_FT_MPI */
     }
 
     /*
@@ -327,6 +361,18 @@ int ompi_request_default_test_some(
     for( i = 0; i < num_requests_done; i++) {
         request = requests[indices[i]];
 
+#if OPAL_ENABLE_FT_MPI
+        /* Special case for MPI_ANY_SOURCE */
+        if(OPAL_UNLIKELY( MPI_ERR_PROC_FAILED_PENDING == request->req_status.MPI_ERROR )) {
+            if (MPI_STATUSES_IGNORE != statuses) {
+                OMPI_COPY_STATUS(&statuses[i], request->req_status, true);
+                statuses[i].MPI_ERROR = MPI_ERR_PROC_FAILED_PENDING;
+            }
+            rc = MPI_ERR_PROC_FAILED_PENDING;
+            continue;
+        }
+#endif /* OPAL_ENABLE_FT_MPI */
+
         /* See note above: if a generalized request completes, we
            *have* to call the query fn, even if STATUSES_IGNORE
            was supplied */
@@ -339,6 +385,12 @@ int ompi_request_default_test_some(
 
         if (MPI_SUCCESS != request->req_status.MPI_ERROR) {
             rc = MPI_ERR_IN_STATUS;
+#if OPAL_ENABLE_FT_MPI
+            if (MPI_ERR_PROC_FAILED == request->req_status.MPI_ERROR
+             || MPI_ERR_REVOKED == request->req_status.MPI_ERROR) {
+                rc = request->req_status.MPI_ERROR;
+            }
+#endif /* OPAL_ENABLE_FT_MPI */
         }
 
         if( request->req_persistent ) {
