@@ -3,7 +3,7 @@
  * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
  *                         University Research and Technology
  *                         Corporation.  All rights reserved.
- * Copyright (c) 2004-2013 The University of Tennessee and The University
+ * Copyright (c) 2004-2024 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
@@ -111,6 +111,8 @@ void mca_rcache_grdma_module_init(mca_rcache_grdma_module_t *rcache,
     OBJ_RETAIN(cache);
     rcache->cache = cache;
 
+    mca_rcache_base_module_init(&rcache->super);
+
     rcache->super.rcache_component = &mca_rcache_grdma_component.super;
     rcache->super.rcache_register = mca_rcache_grdma_register;
     rcache->super.rcache_find = mca_rcache_grdma_find;
@@ -602,6 +604,8 @@ static void mca_rcache_grdma_finalize(mca_rcache_base_module_t *rcache)
 
     OBJ_DESTRUCT(&rcache_grdma->reg_list);
 
+    mca_rcache_base_module_fini(rcache);
+
     /* this rcache was allocated by grdma_init in rcache_grdma_component.c */
     free(rcache);
 }
