@@ -1,6 +1,8 @@
 /*
  * Copyright (c) 2014      Mellanox Technologies, Inc.
  *                         All rights reserved.
+ * Copyright (c) 2019      Research Organization for Information Science
+ *                         and Technology (RIST).  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -36,7 +38,6 @@
 #include "opal/util/output.h"
 #include "opal/util/path.h"
 #include "opal/util/show_help.h"
-#include "orte/util/show_help.h"
 
 #include "oshmem/proc/proc.h"
 #include "oshmem/mca/sshmem/sshmem.h"
@@ -62,11 +63,7 @@ module_init(void);
 static int
 segment_create(map_segment_t *ds_buf,
                const char *file_name,
-               size_t size);
-
-static int
-ds_copy(const map_segment_t *from,
-        map_segment_t *to);
+               size_t size, long hint);
 
 static void *
 segment_attach(map_segment_t *ds_buf, sshmem_mkey_t *mkey);
@@ -88,7 +85,6 @@ mca_sshmem_mmap_module_t mca_sshmem_mmap_module = {
     {
         module_init,
         segment_create,
-        ds_copy,
         segment_attach,
         segment_detach,
         segment_unlink,
@@ -96,36 +92,6 @@ mca_sshmem_mmap_module_t mca_sshmem_mmap_module = {
     }
 };
 
-/* ////////////////////////////////////////////////////////////////////////// */
-/* private utility functions */
-/* ////////////////////////////////////////////////////////////////////////// */
-
-/* ////////////////////////////////////////////////////////////////////////// */
-/**
- * completely resets the contents of *ds_buf
- */
-static inline void
-shmem_ds_reset(map_segment_t *ds_buf)
-{
-    OPAL_OUTPUT_VERBOSE(
-        (70, oshmem_sshmem_base_framework.framework_output,
-         "%s: %s: shmem_ds_resetting "
-         "(id: %d, size: %lu, name: %s)\n",
-         mca_sshmem_mmap_component.super.base_version.mca_type_name,
-         mca_sshmem_mmap_component.super.base_version.mca_component_name,
-         ds_buf->seg_id, (unsigned long)ds_buf->seg_size, ds_buf->seg_name)
-    );
-
-    MAP_SEGMENT_RESET_FLAGS(ds_buf);
-    ds_buf->seg_id = MAP_SEGMENT_SHM_INVALID;
-    ds_buf->seg_base_addr = 0;
-    ds_buf->end = 0;
-    ds_buf->seg_size = 0;
-    ds_buf->type = MAP_SEGMENT_UNKNOWN;
-    unlink(ds_buf->seg_name);
-    memset(ds_buf->seg_name, '\0', sizeof(ds_buf->seg_name));
-}
-
 /* ////////////////////////////////////////////////////////////////////////// */
 static int
 module_init(void)
@@ -142,41 +108,21 @@ module_finalize(void)
     return OSHMEM_SUCCESS;
 }
 
-/* ////////////////////////////////////////////////////////////////////////// */
-static int
-ds_copy(const map_segment_t *from,
-        map_segment_t *to)
-{
-    memcpy(to, from, sizeof(map_segment_t));
-
-    OPAL_OUTPUT_VERBOSE(
-        (70, oshmem_sshmem_base_framework.framework_output,
-         "%s: %s: ds_copy complete "
-         "from: (id: %d, size: %lu, "
-         "name: %s flags: 0x%02x) "
-         "to: (id: %d, size: %lu, "
-         "name: %s flags: 0x%02x)\n",
-         mca_sshmem_mmap_component.super.base_version.mca_type_name,
-         mca_sshmem_mmap_component.super.base_version.mca_component_name,
-         from->seg_id, (unsigned long)from->seg_size, from->seg_name,
-         from->flags, to->seg_id, (unsigned long)to->seg_size, to->seg_name,
-         to->flags)
-    );
-
-    return OSHMEM_SUCCESS;
-}
-/* ////////////////////////////////////////////////////////////////////////// */
 
 static int
 segment_create(map_segment_t *ds_buf,
                const char *file_name,
-               size_t size)
+               size_t size, long hint)
 {
     int rc = OSHMEM_SUCCESS;
     void *addr = NULL;
 
     assert(ds_buf);
 
+    if (hint) {
+        return OSHMEM_ERR_NOT_IMPLEMENTED;
+    }
+
     /* init the contents of map_segment_t */
     shmem_ds_reset(ds_buf);
 
@@ -196,7 +142,7 @@ segment_create(map_segment_t *ds_buf,
                 "create segment failure",
                 true,
                 "mmap",
-                orte_process_info.nodename, (unsigned long long) size,
+                ompi_process_info.nodename, (unsigned long long) size,
                 strerror(errno), errno);
         opal_show_help("help-oshmem-sshmem-mmap.txt",
                        "mmap:create segment failure",
@@ -218,18 +164,18 @@ segment_create(map_segment_t *ds_buf,
          */
         ds_buf->seg_id = oshmem_my_proc_id();
     }
-    ds_buf->seg_base_addr = addr;
-    ds_buf->seg_size = size;
-    ds_buf->end = (void*)((uintptr_t)ds_buf->seg_base_addr + ds_buf->seg_size);
+    ds_buf->super.va_base = addr;
+    ds_buf->seg_size      = size;
+    ds_buf->super.va_end  = (void*)((uintptr_t)ds_buf->super.va_base + ds_buf->seg_size);
 
     OPAL_OUTPUT_VERBOSE(
           (70, oshmem_sshmem_base_framework.framework_output,
            "%s: %s: create %s "
-           "(id: %d, addr: %p size: %lu, name: %s)\n",
+           "(id: %d, addr: %p size: %lu)\n",
            mca_sshmem_mmap_component.super.base_version.mca_type_name,
            mca_sshmem_mmap_component.super.base_version.mca_component_name,
            (rc ? "failure" : "successful"),
-           ds_buf->seg_id, ds_buf->seg_base_addr, (unsigned long)ds_buf->seg_size, ds_buf->seg_name)
+           ds_buf->seg_id, ds_buf->super.va_base, (unsigned long)ds_buf->seg_size)
       );
 
     return rc;
@@ -316,10 +262,10 @@ segment_attach(map_segment_t *ds_buf, sshmem_mkey_t *mkey)
     OPAL_OUTPUT_VERBOSE(
         (70, oshmem_sshmem_base_framework.framework_output,
          "%s: %s: attach successful "
-            "(id: %d, addr: %p size: %lu, name: %s | va_base: 0x%p len: %d key %llx)\n",
+            "(id: %d, addr: %p size: %lu | va_base: 0x%p len: %d key %llx)\n",
             mca_sshmem_mmap_component.super.base_version.mca_type_name,
             mca_sshmem_mmap_component.super.base_version.mca_component_name,
-            ds_buf->seg_id, ds_buf->seg_base_addr, (unsigned long)ds_buf->seg_size, ds_buf->seg_name,
+            ds_buf->seg_id, ds_buf->super.va_base, (unsigned long)ds_buf->seg_size,
             mkey->va_base, mkey->len, (unsigned long long)mkey->u.key)
         );
 
@@ -338,13 +284,13 @@ segment_detach(map_segment_t *ds_buf, sshmem_mkey_t *mkey)
     OPAL_OUTPUT_VERBOSE(
         (70, oshmem_sshmem_base_framework.framework_output,
          "%s: %s: detaching "
-            "(id: %d, addr: %p size: %lu, name: %s)\n",
+            "(id: %d, addr: %p size: %lu)\n",
             mca_sshmem_mmap_component.super.base_version.mca_type_name,
             mca_sshmem_mmap_component.super.base_version.mca_component_name,
-            ds_buf->seg_id, ds_buf->seg_base_addr, (unsigned long)ds_buf->seg_size, ds_buf->seg_name)
+            ds_buf->seg_id, ds_buf->super.va_base, (unsigned long)ds_buf->seg_size)
     );
 
-    munmap((void *)ds_buf->seg_base_addr, ds_buf->seg_size);
+    munmap((void *)ds_buf->super.va_base, ds_buf->seg_size);
 
     /* reset the contents of the map_segment_t associated with this
      * shared memory segment.
@@ -363,10 +309,10 @@ segment_unlink(map_segment_t *ds_buf)
     OPAL_OUTPUT_VERBOSE(
         (70, oshmem_sshmem_base_framework.framework_output,
          "%s: %s: unlinking "
-            "(id: %d, addr: %p size: %lu, name: %s)\n",
+            "(id: %d, addr: %p size: %lu)\n",
             mca_sshmem_mmap_component.super.base_version.mca_type_name,
             mca_sshmem_mmap_component.super.base_version.mca_component_name,
-            ds_buf->seg_id, ds_buf->seg_base_addr, (unsigned long)ds_buf->seg_size, ds_buf->seg_name)
+            ds_buf->seg_id, ds_buf->super.va_base, (unsigned long)ds_buf->seg_size)
     );
 
     /* don't completely reset.  in particular, only reset
