@@ -3,10 +3,10 @@
  *                         All rights reserved.
  * Copyright (c) 2013 Cisco Systems, Inc.  All rights reserved.
  * $COPYRIGHT$
- * 
+ *
  * Additional copyrights may follow
- * 
- * $HEADER$	
+ *
+ * $HEADER$
  */
 
 #include "oshmem_config.h"
@@ -18,19 +18,25 @@
 #include "ompi/datatype/ompi_datatype.h"
 #include "stdio.h"
 
+#if OSHMEM_PROFILING
+#include "oshmem/shmem/fortran/pbindings.h"
+SHMEM_GENERATE_WEAK_BINDINGS(SHMEM_PUT64, shmem_put64)
+#include "oshmem/shmem/fortran/profile-defines.h"
+#endif
+
 SHMEM_GENERATE_FORTRAN_BINDINGS_SUB (void,
         SHMEM_PUT64,
         shmem_put64_,
         shmem_put64__,
         shmem_put64_f,
-        (FORTRAN_POINTER_T target, FORTRAN_POINTER_T source, MPI_Fint *length, MPI_Fint *pe), 
+        (FORTRAN_POINTER_T target, FORTRAN_POINTER_T source, MPI_Fint *length, MPI_Fint *pe),
         (target,source,length,pe) )
 
 void shmem_put64_f(FORTRAN_POINTER_T target, FORTRAN_POINTER_T source, MPI_Fint *length, MPI_Fint *pe)
 {
-    MCA_SPML_CALL(put(FPTR_2_VOID_PTR(target), 
-        OMPI_FINT_2_INT(*length) * 8, 
-        FPTR_2_VOID_PTR(source), 
+    MCA_SPML_CALL(put(oshmem_ctx_default, FPTR_2_VOID_PTR(target),
+        OMPI_FINT_2_INT(*length) * 8,
+        FPTR_2_VOID_PTR(source),
         OMPI_FINT_2_INT(*pe)));
 }
-   
+
