@@ -1,10 +1,12 @@
-/* -*- Mode: C; c-basic-offset:4 ; -*- */
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil -*- */
 /*
  * Copyright (c) 2004-2017 The University of Tennessee and The University
  *                         of Tennessee Research Foundation.  All rights
  *                         reserved.
  * Copyright (c) 2011-2013 Cisco Systems, Inc.  All rights reserved.
  * Copyright (c) 2014-2015 Intel, Inc. All rights reserved.
+ * Copyright (c) 2018      Triad National Security, LLC. All rights
+ *                         reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -19,6 +21,7 @@
 #include "opal/datatype/opal_convertor.h"
 #include "ompi/datatype/ompi_datatype.h"
 #include "opal/util/output.h"
+#include "opal/runtime/opal.h"
 
 /**
  * The purpose of this test is to simulate the multi-network packing and
@@ -178,9 +181,9 @@ unpack_segments( ompi_datatype_t* datatype, int count,
 }
 
 #if (OPAL_ENABLE_DEBUG == 1) && (OPAL_C_HAVE_VISIBILITY == 0)
-extern bool opal_unpack_debug;
-extern bool opal_pack_debug;
-extern bool opal_position_debug ;
+extern bool opal_ddt_unpack_debug;
+extern bool opal_ddt_pack_debug;
+extern bool opal_ddt_position_debug ;
 #endif  /* OPAL_ENABLE_DEBUG */
 
 int main( int argc, char* argv[] )
@@ -199,16 +202,16 @@ int main( int argc, char* argv[] )
         recv_buffer[i] = 0xdeadbeef;
     }
 
-    opal_datatype_init();
+    opal_init(NULL, NULL);
     ompi_datatype_init();
 
     ompi_datatype_create_vector(NELT/2, 1, 2, MPI_INT, &datatype);
     ompi_datatype_commit(&datatype);
 
 #if (OPAL_ENABLE_DEBUG == 1) && (OPAL_C_HAVE_VISIBILITY == 0)
-    opal_unpack_debug   = false;
-    opal_pack_debug     = false;
-    opal_position_debug = false;
+    opal_ddt_unpack_debug   = false;
+    opal_ddt_pack_debug     = false;
+    opal_ddt_position_debug = false;
 #endif  /* OPAL_ENABLE_DEBUG */
 
     create_segments( datatype, 1, fragment_size,
@@ -244,7 +247,7 @@ int main( int argc, char* argv[] )
     }
     free(segments);
 
-    ompi_datatype_finalize();
+    opal_finalize_util ();
 
     return (0 == errors ? 0 : -1);
 }
