@@ -1,40 +1,38 @@
-#include "ompi_config.h"
+/* -*- Mode: C; c-basic-offset:4 ; indent-tabs-mode:nil -*- */
+/*
+ * Copyright (c) 2010      Cisco Systems, Inc.  All rights reserved.
+ * Copyright (c) 2014      The University of Tennessee and The University
+ *                         of Tennessee Research Foundation.  All rights
+ *                         reserved.
+ * Copyright (c) 2018      Los Alamos National Security, LLC. All rights
+ *                         reserved.
+ * $COPYRIGHT$
+ */
+
+#include "opal_config.h"
 
 #include <stdio.h>
 
 #include "support.h"
 #include "opal/constants.h"
-#include "opal/threads/threads.h"
+#include "opal/mca/threads/threads.h"
 #include "opal/sys/atomic.h"
 
 
-#if !OMPI_HAVE_THREAD_SUPPORT
-
-/* If we don't have thread support, there's no point in running this
-   test */
-
-int main(int argc, char *argv[])
-{
-    printf("OMPI was compiled without thread support -- skipping this test\n");
-    return 77;
-}
-
-#else
-
 /* Only have the body of this test if we have thread support */
 
-static volatile int count = 0;
+static opal_atomic_int_t count = 0;
 
 
 static void* thr1_run(opal_object_t* obj)
 {
-    opal_atomic_add(&count, 1);
+    opal_atomic_add (&count, 1);
     return NULL;
 }
 
 static void* thr2_run(opal_object_t* obj)
 {
-    opal_atomic_add(&count, 2);
+    opal_atomic_add (&count, 2);
     return NULL;
 }
 
@@ -57,7 +55,7 @@ int main(int argc, char** argv)
 
     rc = opal_thread_start(&thr2);
     test_verify_int(OPAL_SUCCESS, rc);
-   
+
     rc = opal_thread_join(&thr1, NULL);
     test_verify_int(OPAL_SUCCESS, rc);
 
@@ -67,5 +65,3 @@ int main(int argc, char** argv)
     test_verify_int(3, count);
     return test_finalize();
 }
-
-#endif /* OMPI_HAVE_THREAD_SUPPORT */
